@@ -15,20 +15,19 @@
 # under the License.
 import sys
 
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
+import designate.conf
 from designate import hookpoints
 from designate import service
 from designate import utils
 from designate import version
-from designate.central import service as central
+from designate.central import service as central_service
 
 
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 CONF.import_opt('workers', 'designate.central', group='service:central')
-CONF.import_opt('threads', 'designate.central', group='service:central')
 
 
 def main():
@@ -38,6 +37,9 @@ def main():
 
     hookpoints.log_hook_setup()
 
-    server = central.Service(threads=CONF['service:central'].threads)
+    server = central_service.Service()
+    heartbeat = service.Heartbeat(server.service_name, server.tg,
+                                  rpc_api=server)
     service.serve(server, workers=CONF['service:central'].workers)
+    heartbeat.start()
     service.wait()
