@@ -15,22 +15,19 @@
 # under the License.
 import sys
 
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
-from designate.i18n import _LE
+import designate.conf
 from designate import hookpoints
 from designate import service
 from designate import utils
 from designate import version
 from designate.producer import service as producer_service
 
-
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 CONF.import_opt('workers', 'designate.producer', group='service:producer')
-CONF.import_opt('threads', 'designate.producer', group='service:producer')
 
 
 def main():
@@ -38,16 +35,10 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    # NOTE(timsim): This is to ensure people don't start the wrong
-    #               services when the worker model is enabled.
-    if not cfg.CONF['service:worker'].enabled:
-        LOG.error(_LE('You do not have designate-worker enabled, starting '
-                      'designate-producer is not allowed. '
-                      'You need to start designate-zone-manager instead.'))
-        sys.exit(1)
-
     hookpoints.log_hook_setup()
 
-    server = producer_service.Service(threads=CONF['service:producer'].threads)
+    server = producer_service.Service()
+    heartbeat = service.Heartbeat(server.service_name, server.tg)
     service.serve(server, workers=CONF['service:producer'].workers)
+    heartbeat.start()
     service.wait()
