@@ -15,10 +15,10 @@
 # under the License.
 import sys
 
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
+import designate.conf
 from designate import hookpoints
 from designate import service
 from designate import utils
@@ -26,9 +26,8 @@ from designate import version
 from designate.worker import service as worker_service
 
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 CONF.import_opt('workers', 'designate.worker', group='service:worker')
-CONF.import_opt('threads', 'designate.worker', group='service:worker')
 
 
 def main():
@@ -36,16 +35,10 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    # NOTE(timsim): This is to ensure people don't start the wrong
-    #               services when the worker model is enabled.
-    if not cfg.CONF['service:worker'].enabled:
-        LOG.error('You do not have designate-worker enabled, starting '
-                  'designate-worker is not allowed. '
-                  'You need to start designate-pool-manager instead.')
-        sys.exit(1)
-
     hookpoints.log_hook_setup()
 
-    server = worker_service.Service(threads=CONF['service:worker'].threads)
+    server = worker_service.Service()
+    heartbeat = service.Heartbeat(server.service_name, server.tg)
     service.serve(server, workers=CONF['service:worker'].workers)
+    heartbeat.start()
     service.wait()
