@@ -19,126 +19,100 @@
 import math
 import time
 
-from oslo_config import cfg
 from oslo_log import log
 import tenacity
 import tooz.coordination
 
+import designate.conf
 from designate.utils import generate_uuid
-from designate.i18n import _LI
-from designate.i18n import _LW
-from designate.i18n import _LE
-
 
+CONF = designate.conf.CONF
 LOG = log.getLogger(__name__)
 
-coordination_group = cfg.OptGroup(
-    name='coordination', title="Configuration for coordination"
-)
-
-coordination_opts = [
-    cfg.StrOpt('backend_url',
-               help='The backend URL to use for distributed coordination. If '
-                    'unset services that need coordination will function as '
-                    'a standalone service. This is a `tooz` url - see '
-                    'https://docs.openstack.org/tooz/latest/user/compatibility.html'),  # noqa
-    cfg.FloatOpt('heartbeat_interval',
-                 default=1.0,
-                 help='Number of seconds between heartbeats for distributed '
-                      'coordination.'),
-    cfg.FloatOpt('run_watchers_interval',
-                 default=10.0,
-                 help='Number of seconds between checks to see if group '
-                      'membership has changed')
-
-]
-cfg.CONF.register_group(coordination_group)
-cfg.CONF.register_opts(coordination_opts, group=coordination_group)
-
-CONF = cfg.CONF
-
 
 def _retry_if_tooz_error(exception):
     """Return True if we should retry, False otherwise"""
     return isinstance(exception, tooz.coordination.ToozError)
 
 
-class CoordinationMixin(object):
-    def __init__(self, *args, **kwargs):
-        super(CoordinationMixin, self).__init__(*args, **kwargs)
-
+class Coordination(object):
+    def __init__(self, name, tg):
+        self.name = name
+        self.tg = tg
+        self.coordination_id = None
         self._coordinator = None
+        self._started = False
+
+    @property
+    def coordinator(self):
+        return self._coordinator
+
+    @property
+    def started(self):
+        return self._started
 
     def start(self):
-        self._coordination_id = ":".join([CONF.host, generate_uuid()])
+        self.coordination_id = ":".join([CONF.host, generate_uuid()])
 
         if CONF.coordination.backend_url is not None:
-            backend_url = cfg.CONF.coordination.backend_url
+            backend_url = CONF.coordination.backend_url
 
             self._coordinator = tooz.coordination.get_coordinator(
-                backend_url, self._coordination_id)
-            self._coordination_started = False
+                backend_url, self.coordination_id.encode())
+            self._started = False
 
-            self.tg.add_timer(cfg.CONF.coordination.heartbeat_interval,
+            self.tg.add_timer(CONF.coordination.heartbeat_interval,
                               self._coordinator_heartbeat)
-            self.tg.add_timer(cfg.CONF.coordination.run_watchers_interval,
+            self.tg.add_timer(CONF.coordination.run_watchers_interval,
                               self._coordinator_run_watchers)
 
         else:
-            msg = _LW("No coordination backend configured, distributed "
-                      "coordination functionality will be disabled. "
-                      "Please configure a coordination backend.")
-            LOG.warning(msg)
-
-        super(CoordinationMixin, self).start()
+            LOG.warning("No coordination backend configured, distributed "
+                        "coordination functionality will be disabled. "
+                        "Please configure a coordination backend.")
 
         if self._coordinator is not None:
-            while not self._coordination_started:
+            while not self._started:
                 try:
                     self._coordinator.start()
 
                     try:
                         create_group_req = self._coordinator.create_group(
-                            self.service_name)
+                            self.name)
                         create_group_req.get()
                     except tooz.coordination.GroupAlreadyExist:
                         pass
 
-                    join_group_req = self._coordinator.join_group(
-                        self.service_name)
+                    join_group_req = self._coordinator.join_group(self.name)
                     join_group_req.get()
 
-                    self._coordination_started = True
+                    self._started = True
 
                 except Exception:
-                    LOG.warning(_LW("Failed to start Coordinator:"),
-                                exc_info=True)
+                    LOG.warning("Failed to start Coordinator:", exc_info=True)
                     time.sleep(15)
 
     def stop(self):
         if self._coordinator is not None:
-            self._coordination_started = False
+            self._started = False
 
-            leave_group_req = self._coordinator.leave_group(self.service_name)
+            leave_group_req = self._coordinator.leave_group(self.name)
             leave_group_req.get()
             self._coordinator.stop()
 
-        super(CoordinationMixin, self).stop()
-
         self._coordinator = None
 
     def _coordinator_heartbeat(self):
-        if not self._coordination_started:
+        if not self._started:
             return
 
         try:
             self._coordinator.heartbeat()
         except tooz.coordination.ToozError:
-            LOG.exception(_LE('Error sending a heartbeat to coordination '
-                          'backend.'))
+            LOG.exception('Error sending a heartbeat to coordination backend.')
 
     def _coordinator_run_watchers(self):
-        if not self._coordination_started:
+        if not self._started:
             return
 
         self._coordinator.run_watchers()
@@ -156,9 +130,9 @@ class Partitioner(object):
         self._callbacks = []
 
     def _warn_no_backend(self):
-        LOG.warning(_LW('No coordination backend configured, assuming we are '
-                        'the only worker. Please configure a coordination '
-                        'backend'))
+        LOG.warning('No coordination backend configured, assuming we are '
+                    'the only worker. Please configure a coordination '
+                    'backend')
 
     @tenacity.retry(stop=tenacity.stop_after_attempt(5),
                     wait=tenacity.wait_random(max=2),
@@ -170,17 +144,17 @@ class Partitioner(object):
             return get_members_req.get()
 
         except tooz.coordination.GroupNotCreated:
-            LOG.error(_LE('Attempting to partition over a non-existent group: '
-                          '%s'), self._group_id)
+            LOG.error('Attempting to partition over a non-existent group: %s',
+                      self._group_id)
 
             raise
         except tooz.coordination.ToozError:
-            LOG.error(_LE('Error getting group membership info from '
-                          'coordination backend.'))
+            LOG.error('Error getting group membership info from coordination '
+                      'backend.')
             raise
 
     def _on_group_change(self, event):
-        LOG.debug("Received member change %s" % event)
+        LOG.debug("Received member change %s", event)
         members, self._my_partitions = self._update_partitions()
 
         self._run_callbacks(members, event)
@@ -235,7 +209,7 @@ class Partitioner(object):
         self._started = True
 
     def watch_partition_change(self, callback):
-        LOG.debug("Watching for change %s" % self._group_id)
+        LOG.debug("Watching for change %s", self._group_id)
         self._callbacks.append(callback)
         if self._started:
             if not self._coordinator:
@@ -244,86 +218,3 @@ class Partitioner(object):
 
     def unwatch_partition_change(self, callback):
         self._callbacks.remove(callback)
-
-
-class LeaderElection(object):
-    def __init__(self, coordinator, group_id):
-        self._coordinator = coordinator
-        self._group_id = group_id
-
-        self._callbacks = []
-        self._started = False
-        self._leader = False
-
-    def _warn_no_backend(self):
-        LOG.warning(_LW('No coordination backend configured, assuming we are '
-                        'the leader. Please configure a coordination backend'))
-
-    def start(self):
-        self._started = True
-
-        if self._coordinator:
-            LOG.info(_LI('Starting leader election for group %(group)s'),
-                     {'group': self._group_id})
-
-            # Nominate myself for election
-            self._coordinator.watch_elected_as_leader(
-                self._group_id, self._on_elected_leader)
-        else:
-            self._warn_no_backend()
-            self._leader = True
-
-            for callback in self._callbacks:
-                callback(None)
-
-    def stop(self):
-        self._started = False
-
-        if self._coordinator:
-            LOG.info(_LI('Stopping leader election for group %(group)s'),
-                     {'group': self._group_id})
-
-            # Remove the elected_as_leader callback
-            self._coordinator.unwatch_elected_as_leader(
-                self._group_id, self._on_elected_leader)
-
-            if self._leader:
-                # Tell Tooz we no longer wish to be the leader
-                LOG.info(_LI('Standing down as leader candidate for group '
-                             '%(group)s'), {'group': self._group_id})
-                self._leader = False
-                self._coordinator.stand_down_group_leader(self._group_id)
-
-        elif self._leader:
-            LOG.info(_LI('Standing down as leader candidate for group '
-                         '%(group)s'), {'group': self._group_id})
-            self._leader = False
-
-    @property
-    def is_leader(self):
-        return self._leader
-
-    def _on_elected_leader(self, event):
-        LOG.info(_LI('Successfully elected as leader of group %(group)s'),
-                 {'group': self._group_id})
-        self._leader = True
-
-        for callback in self._callbacks:
-            callback(event)
-
-    def watch_elected_as_leader(self, callback):
-        self._callbacks.append(callback)
-
-        if self._started and self._leader:
-            # We're started, and we're the leader, we should trigger the
-            # callback
-            callback(None)
-
-        elif self._started and not self._coordinator:
-            # We're started, and there's no coordination backend configured,
-            # we assume we're leader and call the callback.
-            self._warn_no_backend()
-            callback(None)
-
-    def unwatch_elected_as_leader(self, callback):
-        self._callbacks.remove(callback)
