@@ -16,15 +16,12 @@
 import time
 import hashlib
 
-from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_db import options
 from sqlalchemy import select, distinct, func
 from sqlalchemy.sql.expression import or_
 
 from designate import exceptions
 from designate import objects
-from designate.i18n import _LI
 from designate.sqlalchemy import base as sqlalchemy_base
 from designate.storage import base as storage_base
 from designate.storage.impl_sqlalchemy import tables
@@ -34,13 +31,6 @@ LOG = logging.getLogger(__name__)
 
 MAXIMUM_SUBZONE_DEPTH = 128
 
-storage_group = cfg.OptGroup(
-    name='storage:sqlalchemy', title="Configuration for SQLAlchemy Storage"
-)
-
-cfg.CONF.register_group(storage_group)
-cfg.CONF.register_opts(options.database_opts, group=storage_group)
-
 
 class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     """SQLAlchemy connection"""
@@ -476,10 +466,10 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             limit=limit,
         )
         if not zones:
-            LOG.info(_LI("No zones to be purged"))
+            LOG.info("No zones to be purged")
             return
 
-        LOG.debug(_LI("Purging %d zones"), len(zones))
+        LOG.debug("Purging %d zones", len(zones))
 
         zones_by_id = {z.id: z for z in zones}
 
@@ -492,11 +482,11 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
                 values(parent_zone_id=surviving_parent_id)
 
             resultproxy = self.session.execute(query)
-            LOG.debug(_LI("%d child zones updated"), resultproxy.rowcount)
+            LOG.debug("%d child zones updated", resultproxy.rowcount)
 
             self.purge_zone(context, zone)
 
-        LOG.info(_LI("Purged %d zones"), len(zones))
+        LOG.info("Purged %d zones", len(zones))
         return len(zones)
 
     def count_zones(self, context, criterion=None):
@@ -1499,8 +1489,8 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
 
         if not context.all_tenants:
             query = query.where(or_(
-                table.c.tenant_id == context.tenant,
-                table.c.target_tenant_id == context.tenant))
+                table.c.tenant_id == context.project_id,
+                table.c.target_tenant_id == context.project_id))
 
         return self._find(
             context, table, objects.ZoneTransferRequest,
