@@ -36,34 +36,6 @@ from designate.i18n import _
 
 LOG = logging.getLogger(__name__)
 
-
-helper_opts = [
-    cfg.StrOpt('root-helper',
-               default='sudo designate-rootwrap /etc/designate/rootwrap.conf',
-               help='designate-rootwrap configuration')
-]
-
-
-# Set some proxy options (Used for clients that need to communicate via a
-# proxy)
-proxy_group = cfg.OptGroup(
-    name='proxy', title="Configuration for Client Proxy"
-)
-
-proxy_opts = [
-    cfg.StrOpt('http_proxy',
-               help='Proxy HTTP requests via this proxy.'),
-    cfg.StrOpt('https_proxy',
-               help='Proxy HTTPS requests via this proxy'),
-    cfg.ListOpt('no_proxy', default=[],
-                help='These addresses should not be proxied')
-]
-
-
-cfg.CONF.register_opts(helper_opts)
-cfg.CONF.register_group(proxy_group)
-cfg.CONF.register_opts(proxy_opts, proxy_group)
-
 # Default TCP/UDP ports
 
 DEFAULT_AGENT_PORT = 5358
@@ -110,29 +82,6 @@ def read_config(prog, argv):
              default_config_files=config_files)
     config.set_defaults()
 
-    register_plugin_opts()
-
-    # Avoid circular dependency imports
-    from designate import pool_manager
-    pool_manager.register_dynamic_pool_options()
-
-
-def register_plugin_opts():
-    # Avoid circular dependency imports
-    from designate import plugin
-
-    # Register Producer Tasks
-    plugin.Plugin.register_cfg_opts('designate.producer_tasks')
-    plugin.Plugin.register_extra_cfg_opts('designate.producer_tasks')
-
-    # Register Backend Plugin Config Options
-    plugin.Plugin.register_cfg_opts('designate.backend')
-    plugin.Plugin.register_extra_cfg_opts('designate.backend')
-
-    # Register Agent Backend Plugin Config Options
-    plugin.Plugin.register_cfg_opts('designate.backend.agent_backend')
-    plugin.Plugin.register_extra_cfg_opts('designate.backend.agent_backend')
-
 
 def resource_string(*args):
     if len(args) == 0:
@@ -191,55 +140,6 @@ def execute(*cmd, **kw):
                                 root_helper=root_helper, **kw)
 
 
-def get_item_properties(item, fields, mixed_case_fields=None, formatters=None):
-    """Return a tuple containing the item properties.
-
-    :param item: a single item resource (e.g. Server, Tenant, etc)
-    :param fields: tuple of strings with the desired field names
-    :param mixed_case_fields: tuple of field names to preserve case
-    :param formatters: dictionary mapping field names to callables
-        to format the values
-    """
-    row = []
-    mixed_case_fields = mixed_case_fields or []
-    formatters = formatters or {}
-
-    for field in fields:
-        if field in formatters:
-            row.append(formatters[field](item))
-        else:
-            if field in mixed_case_fields:
-                field_name = field.replace(' ', '_')
-            else:
-                field_name = field.lower().replace(' ', '_')
-            if not hasattr(item, field_name) and \
-                    (isinstance(item, dict) and field_name in item):
-                data = item[field_name]
-            else:
-                data = getattr(item, field_name, '')
-            if data is None:
-                data = ''
-            row.append(data)
-    return tuple(row)
-
-
-def get_columns(data):
-    """
-    Some row's might have variable count of columns, ensure that we have the
-    same.
-
-    :param data: Results in [{}, {]}]
-    """
-    columns = set()
-
-    def _seen(col):
-        columns.add(str(col))
-
-    six.moves.map(lambda item: six.moves.map(_seen,
-        list(six.iterkeys(item))), data)
-    return list(columns)
-
-
 def increment_serial(serial=0):
     # This provides for *roughly* unix timestamp based serial numbers
     new_serial = timeutils.utcnow_ts()
@@ -250,44 +150,6 @@ def increment_serial(serial=0):
     return new_serial
 
 
-def quote_string(string):
-    inparts = string.split(' ')
-    outparts = []
-    tmp = None
-
-    for part in inparts:
-        if part == '':
-            continue
-        elif part[0] == '"' and part[-1:] == '"' and part[-2:] != '\\"':
-            # Handle Quoted Words
-            outparts.append(part.strip('"'))
-        elif part[0] == '"':
-            # Handle Start of Quoted Sentance
-            tmp = part[1:]
-        elif tmp is not None and part[-1:] == '"' and part[-2:] != '\\"':
-            # Handle End of Quoted Sentance
-            tmp += " " + part.strip('"')
-            outparts.append(tmp)
-            tmp = None
-        elif tmp is not None:
-            # Handle Middle of Quoted Sentance
-            tmp += " " + part
-        else:
-            # Handle Standalone words
-            outparts.append(part)
-
-    if tmp is not None:
-        # Handle unclosed quoted strings
-        outparts.append(tmp)
-
-    # This looks odd, but both calls are necessary to ensure the end results
-    # is always consistent.
-    outparts = [o.replace('\\"', '"') for o in outparts]
-    outparts = [o.replace('"', '\\"') for o in outparts]
-
-    return '"' + '" "'.join(outparts) + '"'
-
-
 def deep_dict_merge(a, b):
     if not isinstance(b, dict):
         return b
@@ -375,14 +237,6 @@ def get_proxies():
     return proxies
 
 
-def extract_priority_from_data(recordset_type, record):
-    priority, data = None, record['data']
-    if recordset_type in ('MX', 'SRV'):
-        priority, _, data = record['data'].partition(" ")
-        priority = int(priority)
-    return priority, data
-
-
 def cache_result(function):
     """A function decorator to cache the result of the first call, every
     additional call will simply return the cached value.
@@ -502,7 +356,7 @@ def bind_tcp(host, port, tcp_backlog, tcp_keepidle=None):
     sock_tcp.bind((host, port))
     if port == 0:
         newport = sock_tcp.getsockname()[1]
-        LOG.info('Listening on TCP port %(port)d'), {'port': newport}
+        LOG.info('Listening on TCP port %(port)d', {'port': newport})
 
     sock_tcp.listen(tcp_backlog)
 
